@@ -6,7 +6,7 @@ package Mite::Attribute;
 use Mite::Miteception qw( -all !lazy );
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.010002';
+our $VERSION   = '0.010003';
 
 use B ();
 use List::Util ();
@@ -244,26 +244,16 @@ sub BUILD {
     }
 
     if ( defined $self->lvalue ) {
-        if ( $self->lazy ) {
-            require Mite::Shim;
-            Mite::Shim::croak( 'Attributes with lazy defaults cannot have an lvalue accessor' );
-        }
-        elsif ( $self->trigger ) {
-            require Mite::Shim;
-            Mite::Shim::croak( 'Attributes with triggers cannot have an lvalue accessor' );
-        }
-        elsif ( $self->weak_ref ) {
-            require Mite::Shim;
-            Mite::Shim::croak( 'Attributes with weak_ref cannot have an lvalue accessor' );
-        }
-        elsif ( $self->type or $self->coerce ) {
-            require Mite::Shim;
-            Mite::Shim::croak( 'Attributes with type constraints or coercions cannot have an lvalue accessor' );
-        }
-        elsif ( $self->cloner_method ) {
-            require Mite::Shim;
-            Mite::Shim::croak( 'Attributes with autoclone cannot have an lvalue accessor' );
-        }
+        croak( 'Attributes with lazy defaults cannot have an lvalue accessor' )
+            if $self->lazy;
+        croak( 'Attributes with triggers cannot have an lvalue accessor' )
+            if $self->trigger;
+        croak( 'Attributes with weak_ref cannot have an lvalue accessor' )
+            if $self->weak_ref;
+        croak( 'Attributes with type constraints or coercions cannot have an lvalue accessor' )
+            if $self->type || $self->coerce;
+        croak( 'Attributes with autoclone cannot have an lvalue accessor' )
+            if $self->cloner_method;
     }
 }
 
@@ -354,6 +344,31 @@ sub _all_aliases {
     map $self->_expand_name($_), @$aliases;
 }
 
+sub associated_methods {
+    my $self = shift;
+
+    my @methods = grep defined, (
+        $self->_all_aliases,
+        map(
+            $self->_expand_name($self->$_),
+            qw( reader writer accessor clearer predicate lvalue local_writer builder trigger cloner_method ),
+        ),
+    );
+
+    if ( ref $self->handles ) {
+        if ( ! $self->handles_via ) {
+            push @methods, sprintf '_assert_blessed_%s', $self->name;
+        }
+        push @methods, map $self->_expand_name($_), sort keys %{ $self->handles };
+    }
+    elsif ( $self->handles ) {
+        my %delegations = $self->_compile_native_delegations;
+        push @methods, sort keys %delegations;
+    }
+
+    return @methods;
+}
+
 sub _build_type {
     my $self = shift;
 
@@ -1144,7 +1159,7 @@ sub compile {
 
     $code .= "\n";
 
-    if ( my $alias_is_for = $self->alias_is_for ) {
+    if ( $self->alias and my $alias_is_for = $self->alias_is_for ) {
         $code .= sprintf "# Aliases for %s\n", $self->name;
         $code .= '# ' . $self->definition_context_to_pretty_string. "\n";
         my $alias_target = $self->_expand_name( $self->$alias_is_for );
