@@ -6,7 +6,7 @@ package Mite::Package;
 use Mite::Miteception -all;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.010002';
+our $VERSION   = '0.010003';
 
 has name =>
   is            => ro,
@@ -38,6 +38,10 @@ has imported_keywords =>
   isa           => Map[ MethodName, Str ],
   builder       => sub { {} };
 
+has arg =>
+  is            => rw,
+  default       => {};
+
 sub kind { 'package' }
 
 sub BUILD {
